@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 1.10.x SVN: $Id: global.php 2810 2010-01-25 08:32:24Z fishbone $
+ * @version    Release 1.10.x SVN: $Id: global.php 2840 2010-02-09 02:39:23Z fishbone $
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -43,8 +43,8 @@ define('M3_ENCODING',	'UTF-8');	// 内部エンコーディング
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'1.10.5');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2010/1/25');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'1.10.7');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2010/2/8');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -60,6 +60,8 @@ define('M3_SYSTEM_COMMON_PATH',		M3_SYSTEM_INCLUDE_PATH . '/common');	// シス
 // ファイル、ディレクトリ名
 define('M3_SYSTEM_ROOT_DIR_NAME',	basename(M3_SYSTEM_ROOT_PATH));			// ルートディレクトリ名
 define('M3_SYSTEM_ADMIN_DIR_NAME',	'admin');								// システム管理ディレクトリ名
+define('M3_DIR_NAME_TEMPLATES',		'templates');							// テンプレート格納ディレクトリ名
+define('M3_DIR_NAME_WIDGETS',		'widgets');								// ウィジェット格納ディレクトリ名
 define('M3_DIR_NAME_SCRIPTS',		'scripts');								// スクリプト格納ディレクトリ名
 define('M3_DIR_NAME_RESOURCE',		'resource');							// ユーザリソース格納ディレクトリ名
 define('M3_DIR_NAME_CSS',			'css');									// CSS格納ディレクトリ名
