@@ -8,9 +8,9 @@
  *
  * @package    フリーレイアウトお問い合わせ
  * @author     株式会社 毎日メディアサービス
- * @copyright  Copyright 2009 株式会社 毎日メディアサービス.
+ * @copyright  Copyright 2009-2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: contactus_freelayoutWidgetContainer.php 2493 2009-10-31 06:16:06Z fishbone $
+ * @version    SVN: $Id: contactus_freelayoutWidgetContainer.php 2811 2010-01-27 07:17:15Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -291,6 +291,8 @@ class contactus_freelayoutWidgetContainer extends BaseWidgetContainer
 							if (!$enabled) $param[] = 'disabled';		// 使用不可
 							if (count($param) > 0) $paramStr = ' ' . implode($param, ' ');
 							$inputTag .= '<input type="' . $type . '" name="' . $fieldName . '" value="' . $this->convertToDispString($value) . '"' . $paramStr . ' />' . $this->convertToDispString($key) . M3_NL;
+						} else {		// 空項目のときは改行を追加
+							$inputTag .= '<br />' . M3_NL;
 						}
 					}
 					break;
