@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentWidgetContainer.php 2633 2009-12-06 15:25:37Z fishbone $
+ * @version    SVN: $Id: default_contentWidgetContainer.php 2845 2010-02-10 05:39:23Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -27,11 +27,16 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 	private $headDesc;		// METAタグ要約
 	private $headKeyword;	// METAタグキーワード
 	private $showTitle;			// コンテンツタイトルの表示制御
+	private $showEdit;			// 編集ボタンの表示
+	private $isSystemManageUser;	// システム運用可能ユーザかどうか
 	const CONTENT_TYPE = 'ct';		// 参照数カウント用
 	const DEFAULT_SEARCH_LIST_COUNT = 20;			// 最大リスト表示数
 	const MESSAGE_NO_CONTENT		= 'コンテンツが見つかりません';
 	const CONTENT_SIZE = 200;			// 検索結果コンテンツの文字列最大長
 	const DEFAULT_MESSAGE_DENY = 'コンテンツを表示できません';		// アクセス不可の場合のメッセージ
+	const ICON_SIZE = 16;		// アイコンのサイズ
+	const EDIT_ICON_FILE = '/images/system/page_edit.png';		// 編集アイコン
+	const NEW_ICON_FILE = '/images/system/page_add.png';		// 新規アイコン
 	
 	/**
 	 * コンストラクタ
@@ -90,11 +95,12 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 		$this->currentDay = date("Y/m/d");		// 日
 		$this->currentHour = (int)date("H");		// 時間
 		$this->currentPageUrl = $this->gEnv->createCurrentPageUrl();// 現在のページURL
+		$this->isSystemManageUser = $this->gEnv->isSystemManageUser();	// システム運用可能ユーザかどうか
 		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
 				
 		// 管理者でプレビューモードのときは表示制限しない
 		$preview = false;
-		if ($this->gEnv->isSystemManageUser() && $cmd == M3_REQUEST_CMD_PREVIEW){		// システム運用者以上
+		if ($this->isSystemManageUser && $cmd == M3_REQUEST_CMD_PREVIEW){		// システム運用者以上
 			$preview = true;
 		}
 		
@@ -106,11 +112,13 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 		$this->showTitle = 1;			// コンテンツタイトルを表示するかどうか
 		$showMessageDeny = 1;					// アクセス不可の場合にメッセージを表示するかどうか
 		$messageDeny = self::DEFAULT_MESSAGE_DENY;							// アクセス不可の場合のメッセージ
+		$this->showEdit = 1;			// 編集ボタンを表示するかどうか
 		$paramObj = $this->getWidgetParamObj();
 		if (!empty($paramObj)){
 			$this->showTitle = $paramObj->showTitle;			// コンテンツタイトルを表示するかどうか
 			$showMessageDeny = $paramObj->showMessageDeny;					// アクセス不可の場合にメッセージを表示するかどうか
 			$messageDeny = $paramObj->messageDeny;							// アクセス不可の場合のメッセージ
+			$this->showEdit = $paramObj->showEdit;			// 編集ボタンを表示するかどうか
 		}
 			
 		$act = $request->trimValueOf('act');
@@ -159,6 +167,13 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 				$this->setAppErrorMsg('IDにエラー値があります');
 			}
 		}
+		// 運用可能ユーザの場合は編集用ボタンを表示
+		if ($this->isSystemManageUser && $act != 'search'){		// 検索画面以外
+			// 設定画面表示用のスクリプトを埋め込む
+			$editUrl = $this->getConfigAdminUrl('openby=simple&task=content_detail');
+			$this->tmpl->setAttribute('admin_script', 'visibility', 'visible');
+			$this->tmpl->addVar("admin_script", "edit_url", $editUrl);
+		}
 	}
 	/**
 	 * ヘッダ部メタタグの設定
@@ -191,7 +206,7 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 		if (empty($this->showTitle)) $this->tmpl->addVar('contentlist', 'type', 'hide_title');
 		
 		// ビューカウントを更新
-		if (!$this->gEnv->isSystemManageUser()){		// システム運用者以上の場合はカウントしない
+		if (!$this->isSystemManageUser){		// システム運用者以上の場合はカウントしない
 			$this->gInstance->getAnalyzeManager()->updateContentViewCount(self::CONTENT_TYPE, $fetchedRow['cn_serial'], $this->currentDay, $this->currentHour);
 		}
 
@@ -215,10 +230,21 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 		
 		$headClassStr = $this->gDesign->getDefaultContentHeadClassString();			// コンテンツヘッダ用CSSクラス
 
+		// コンテンツ編集権限がある場合はボタンを表示
+		$buttonList = '';
+		if (!empty($this->showEdit) && $this->isSystemManageUser){
+			$iconUrl = $this->gEnv->getRootUrl() . self::EDIT_ICON_FILE;		// 編集アイコン
+			$iconTitle = '編集';
+			$editImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+			$buttonList = '<span style="line-height:0;"><a href="#" onclick="editContent(' . $fetchedRow['cn_id'] . ');">' . $editImg . '</a></span><br />';
+			$buttonList = '<div style="text-align:right;position:absolute;top:10px;z-index:10;width:100%;">' . $buttonList . '</div>';
+		}
+		
 		$row = array(
 			'class' => $headClassStr,		// コンテンツヘッダ用CSSクラス
 			'title' => $this->convertToDispString($fetchedRow['cn_name']),
-			'content' => $contentText	// コンテンツ
+			'content' => $contentText,	// コンテンツ
+			'button_list' => $buttonList	// 記事編集ボタン
 		);
 		$this->tmpl->addVars('contentlist', $row);
 		$this->tmpl->parseTemplate('contentlist', 'a');
